# encoding: utf-8
# frozen_string_literal: true
# This file is distributed under New Relic's license terms.
# See https://github.com/newrelic/newrelic-ruby-agent/blob/main/LICENSE for complete details.

module NewRelic
  module TelemetrySdk
    module Util
      extend self

      HEX_DIGITS = (0..15).map{|i| i.to_s(16)}

      module_function

      # This method intentionally does not use SecureRandom, because it relies
      # on urandom, which raises an exception in MRI when the interpreter runs
      # out of allocated file descriptors.
      # The guids generated by this method may not be _secure_, but they are
      # random enough for our purposes.
      def generate_guid length = 16
        guid = String.new
        length.times do |a|
          guid << HEX_DIGITS[rand(16)]
        end
        guid
      end

      def current_time
        Time.now
      end

      def time_to_ms time = current_time
        (time.to_f * 1000).round
      end
    end
  end
end
